@@ -42,16 +42,26 @@ def read_input_strings(args, axis_data):
                 unit = elems[1]
             name = elems[0]
             axis_str = axis_str.replace("->" + unit, "")
+        # Detect rms sum
+        if "rss" in axis_str:
+            elems = axis_str.split("=rss")
+            name = elems[0]
+            extension = "rss"
         # Detect sum
-        if "sum" in axis_str:
+        elif "sum" in axis_str:
             elems = axis_str.split("=sum")
             name = elems[0]
             extension = "sum"
-        # Detect rms
+        # Detect rms mean
         elif "rms" in axis_str:
             elems = axis_str.split("=rms")
             name = elems[0]
             extension = "rms"
+        # Detect mean
+        elif "mean" in axis_str:
+            elems = axis_str.split("=mean")
+            name = elems[0]
+            extension = "mean"
         # Detect periods
         elif "oneperiod" in axis_str:
             elems = axis_str.split("[")
@@ -123,7 +133,7 @@ def read_input_strings(args, axis_data):
             if ":" in ind_str:
                 elems2 = ind_str.split(":")
                 extension = "interval"
-                indices = [i for i in range(int(elems2[0]), int(elems2[1]) + 1)]
+                indices = [i for i in range(int(elems2[0]), int(elems2[1]))]
             # List of indices
             elif "," in ind_str:
                 extension = "list"
