@@ -44,14 +44,12 @@ def get_along(self, *args, unit="SI", is_norm=False, axis_data=[]):
     # Interpolate over axis values
     values = self.interpolate(values, axes_list)
     # Conversions
-    values = self.convert(values, unit, is_norm)
+    values = self.convert(values, unit, is_norm, axes_list)
     # Return axes and values
     return_dict = {}
     for axis_requested in axes_list:
-        if axis_requested.extension == "sum":
-            return_dict[axis_requested.name] = "sum"
-        elif axis_requested.extension == "rms":
-            return_dict[axis_requested.name] = "rms"
+        if axis_requested.extension in ["sum", "rss", "mean", "rms"]:
+            return_dict[axis_requested.name] = axis_requested.extension
         else:
             return_dict[axis_requested.name] = axis_requested.values
     return_dict[self.symbol] = values
