@@ -24,7 +24,7 @@ def get_axis(self, axis, is_real):
     is_components = getattr(axis, "is_components", False)
     if is_components:
         values = axis.get_values()
-        if self.extension != "sum" and self.extension != "rms":
+        if not self.extension in ["sum", "rss", "mean", "rms"]:
             self.extension = "list"
         if self.indices is not None:
             self.values = values[self.indices]
@@ -68,7 +68,7 @@ def get_axis(self, axis, is_real):
                 is_smallestperiod = False
                 is_oneperiod = True
                 is_antiperiod = False
-        elif self.extension == "rms" or self.extension == "sum":
+        elif self.extension in ["sum", "rss", "mean", "rms"]:
             is_smallestperiod = False
             is_oneperiod = False
             is_antiperiod = False
@@ -94,7 +94,8 @@ def get_axis(self, axis, is_real):
                         is_smallestperiod = False
                         is_oneperiod = False
                         is_antiperiod = False
-                        self.extension = "interval"
+                        if not self.is_pattern:
+                            self.extension = "interval"
             elif self.transform == "ifft":  # Ignore symmetries in ifft case
                 is_smallestperiod = True
                 is_oneperiod = False
@@ -192,5 +193,5 @@ def get_axis(self, axis, is_real):
                 self.values = values
         if self.indices is not None:
             self.values = values[self.indices]
-            if self.extension == "sum" or self.extension == "rms":
+            if self.extension in ["sum", "rss", "mean", "rms"]:
                 self.indices = None
